# DroneBuddyLib

## Introduction

DroneBuddy lib can be used as helper library to program your own drone. this is a offline library, so you can use it
without internet connection, which is required when you are connecting with Tello drone.

This library packs a bunch of functionalities, like: 
1. Tello drone control
2. Object detection given a frame
3. Speech recognition
4. Text to speech conversion
5. Face recognition given a frame
6. Intent recognition given a text

## Installation

### Prerequisites
1. Python 3.10 or higher
2. Need to install rust, use https://www.rust-lang.org/tools/install.

The installation is pretty simple, just run the following command in your terminal:

`pip install dronebuddylib
`
#### Voice Recognition

If you need control the drone with voice commands you can use the following methods.
